VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "clsDFAState"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
Option Explicit

'
' Class clsDFAState (clsDFAState.cls)
'
' Purpose:
'   Simulates a single state in a Deterministic Finite Automaton (DFA).
'
'   The DFA state is defined as follows: If the value of the current cell within
'   the tape is CurrentCellContents, then change its contents to NewCellContents,
'   jump to state NewStateID and move in the direction of NewDirection.
'


'
' Private Variables
'


' The state's no. or identification string.
Private mstrStateID As String
' The contents of the current cell within the tape.
Private mstrCurrentCellContents As String
' The new contents of the current cell (what value should the current cell contain
' after executing this state) - values other than 0,1 are used when the "Tape cells
' can contain textual values" option is checked.
Private mstrNewCellContents As String
' The ID of the state the DFA simulator should move to after executing this state.
Private mstrNewStateID As String
' The direction the read head should move to within the tape (negative no. for left,
' positive no. for right) - values other than -1, 1 are used when the "Read head can
' move more than one step left\right" or "Read head can stay at the same position
' after executing a state" options are checked.
Private mintNewDirection As Integer
' A comment about the state (a description of what it does, for example).
Private mstrComment As String
' Indicates whether this state is an accept state (if true the DFA stops running after
' executing this state).
Private mblnAcceptingState As Boolean
' Is the current DFA state a breakpoint?
Private mblnBreakPoint As Boolean


'
' Public Properties
'


'
' StateID Property
'

Public Property Get StateID() As String
    StateID = mstrStateID
End Property

Public Property Let StateID(NewID As String)
    mstrStateID = NewID
End Property


'
' CurrentCellContents Property
'

Public Property Get CurrentCellContents() As String
    CurrentCellContents = mstrCurrentCellContents
End Property

Public Property Let CurrentCellContents(CellContents As String)
    mstrCurrentCellContents = CellContents
End Property


'
' NewCellContents Property
'

Public Property Get NewCellContents() As String
    NewCellContents = mstrNewCellContents
End Property

Public Property Let NewCellContents(CellContents As String)
    mstrNewCellContents = CellContents
End Property


'
' NewStateID Property
'

Public Property Get NewStateID() As String
    NewStateID = mstrNewStateID
End Property

Public Property Let NewStateID(NewID As String)
    mstrNewStateID = NewID
End Property


'
' NewDirection Property
'

Public Property Get NewDirection() As Integer
    NewDirection = mintNewDirection
End Property

Public Property Let NewDirection(Direction As Integer)
    mintNewDirection = Direction
End Property


'
' Comment Property
'

Public Property Get Comment() As String
    Comment = mstrComment
End Property

Public Property Let Comment(NewComment As String)
    mstrComment = NewComment
End Property


'
' AcceptingState Property
'

Public Property Get AcceptingState() As Boolean
    AcceptingState = mblnAcceptingState
End Property

Public Property Let AcceptingState(Accepting As Boolean)
    mblnAcceptingState = Accepting
End Property


'
' BreakPoint Property
'

Public Property Get BreakPoint() As Boolean
    BreakPoint = mblnBreakPoint
End Property

Public Property Let BreakPoint(Break As Boolean)
    mblnBreakPoint = Break
End Property

